@@ -97,6 +97,18 @@
 #define WM_MOUSEHWHEEL 0x20E
 #endif
 
+/* According to
+ * http://blog.airesoft.co.uk/2009/11/wm_messages/
+ * this is the actual internal name MS uses for this undocumented message.
+ * According to
+ * https://bugs.winehq.org/show_bug.cgi?id=15055
+ * wParam is 0
+ * lParam is a pair of virtual desktop coordinates for the popup
+ */
+#ifndef WM_SYSMENU
+#define WM_SYSMENU 0x313
+#endif
+
 #ifndef CF_DIBV5
 #define CF_DIBV5 17
 #endif
@@ -537,6 +549,9 @@ gboolean _gdk_win32_window_fill_min_max_info    (GdkWindow  *window,
 
 gboolean _gdk_win32_window_lacks_wm_decorations (GdkWindow *window);
 
+BOOL WINAPI GtkShowWindow (HWND hwnd,
+                           int  cmd_show);
+
 /* Initialization */
 void _gdk_win32_windowing_init (void);
 void _gdk_dnd_init    (void);
