@@ -2254,19 +2254,24 @@ gtk_stack_allocate (GtkCssGadget        *gadget,
 
   child_allocation.x = 0;
   child_allocation.y = 0;
-  child_allocation.width = allocation->width;
-  child_allocation.height = allocation->height;
+
 
   if (priv->last_visible_child)
     {
       int min, nat;
-
+      gtk_widget_get_preferred_width (priv->last_visible_child->widget, &min, &nat);
+      child_allocation.width = MAX (min, allocation->width);
       gtk_widget_get_preferred_height_for_width (priv->last_visible_child->widget,
-                                                 allocation->width,
+                                                 child_allocation.width,
                                                  &min, &nat);
+      child_allocation.height = MAX (min, allocation->height);
+
       gtk_widget_size_allocate (priv->last_visible_child->widget, &child_allocation);
     }
 
+  child_allocation.width = allocation->width;
+  child_allocation.height = allocation->height;
+
   if (priv->visible_child)
     {
       int min, nat;
@@ -2285,13 +2290,9 @@ gtk_stack_allocate (GtkCssGadget        *gadget,
           else if (valign == GTK_ALIGN_CENTER &&
                    child_allocation.height > allocation->height)
             child_allocation.y -= (nat - allocation->height) / 2;
+        }
 
-          gtk_widget_size_allocate (priv->visible_child->widget, &child_allocation);
-        }
-      else
-        {
-          gtk_widget_size_allocate (priv->visible_child->widget, &child_allocation);
-        }
+      gtk_widget_size_allocate (priv->visible_child->widget, &child_allocation);
     }
 
    if (gtk_widget_get_realized (widget))
